# 概述

请求报文，Header中需要添加参数

| 参数名称 | 说明     |      |
| -------- | -------- | ---- |
| Token    | 令牌     |      |
| V        | 加密向量 |      |



# 登录模块API接口

## API接口一览表

| 接口分类 | 接口描述 | API接口                   | 权限            |
| :------: | :------- | :------------------------ | --------------- |
| 系统登录 | 系统登录 | /api/auth/invoke          | /XXXX/XXX/XXX/X |
| 系统登录 | 退出登录 | /api/auth/revoke          |                 |
| 系统登录 | 修改密码 | /api/auth/password/change |                 |

## 系统登录

使用用户名和密码登录系统，POST请求

api/auth/invoke

入参示例

```
{
"userName":"xx",
"password":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述     |
| -------- | -------- | ---- | -------- |
| userName | String   | no   | 用户名   |
| password | String   | no   | 用户密码 |

调用成功返回示例

```json
{
   "code":"200",
   "data": 
    {
      "token": "xxx",
      "tokenTimeout": "xxx",
      "tokenActivityTimeout": "xxx"
   },
  "msg":"登陆成功"
}
```

调用成功返回描述

| 变量名               | 变量类型 | 可为NULL | 描述                       |
| -------------------- | -------- | -------- | -------------------------- |
| token                | Integer  | No       | 令牌值                     |
| tokenTimeout         | String   | No       | 令牌超时时间，单位(秒)     |
| tokenActivityTimeout | String   | No       | 令牌活动超时间隔，单位(秒) |

## 退出登录

注销令牌退出登录，POST请求

api/auth/revoke

入参示例

```
{
"userName":"xx",
"token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述   |
| -------- | -------- | ---- | ------ |
| userName | String   | no   | 用户名 |
| token    | String   | no   | token  |

调用成功返回示例

```json
{
   "code":"200",
   "data": "null",
   "msg":"令牌已注销"
}
```

## 修改密码

修改登录密码，POST请求

api/auth/password/change

入参示例

```
{
"userName":"xx",
"oldPassword":"xx",
"newPassword":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名      | 参数类型 | 可选 | 描述   |
| ----------- | -------- | ---- | ------ |
| oldPassword | String   | NO   | 旧密码 |
| newPassword | String   | NO   | 新密码 |
| userName    | String   | NO   | 用户名 |
| token       | String   | NO   | token  |

调用成功返回示例

```json
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

# 公司机构模块API接口

组织机构模块提供的API包括机构查询、添加、修改等功能。

## API接口一览表

|   接口分类   | 接口描述     | API接口            | 权限            |
| :----------: | :----------- | :----------------- | --------------- |
| 公司机构操作 | 公司机构查询 | /api/org/getOrgs   | /XXXX/XXX/XXX/X |
| 公司机构操作 | 添加机构信息 | /api/org/addOrg    |                 |
| 公司机构操作 | 修改机构信息 | /api/org/updateOrg |                 |
| 公司机构操作 | 删除指定机构 | /api/org/deleteOrg |                 |

## 公司机构查询

提供获取所有机构信息的功能，POST方式

> /api/org/getOrgs

入参示例

```
{
"name":"12",
"parentOrgId":"xx",
"mrid":"xxx",
"province":"xx",
"city":"xxx",
"county":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名      | 参数类型 | 可选 | 描述                                   |
| ----------- | -------- | ---- | -------------------------------------- |
| name        | String   | YES  | 机构名称，当名称为空时查询所有机构数据 |
| parentOrgId | String   | YES  | 上级机构ID                             |
| mrid        | String   | YES  | 编码                                   |
| province    | String   | YES  | 省                                     |
| city        | String   | YES  | 城市                                   |
| county      | String   | YES  | 区县                                   |
| token       | String   | NO   | token                                  |

调用成功返回示例

```json
{
   "code":"200",
   "data": [
    {
      "id": "xxx",
      "mrid": "xxx",
      "name": "xxx",
      "aliasName":"xxx",
      "province": "xxx",
      "city": "xxx",
      "county": "xxx",
      "address": "xxx",
      "contactPhone":"xxx",
      "remarks":"xxx",
      "parentOrgId":"xxxx"
   },
    {
        ...
    }
  ],
  "msg":"调用成功"
}
```

调用成功返回描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| id           | Integer  | No       | id         |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |



## 添加机构信息

根据添加的机构信息创建机构，POST方式

>/api/org/addOrg

入参示例

```
 {
      "mrid": "xxx",
      "name": "xxx",
      "aliasName":"xxx",
      "province": "xxx",
      "city": "xxx",
      "county": "xxx",
      "address": "xxx",
      "contactPhone":"xxx",
      "remarks":"xxx",
      "parentOrgId":"xxxx",
       "token":"xxx"
   }
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |
| token        | String   | NO       | token      |

调用成功返回示例

```
{
"code":"200",
"msg":"添加成功",
"data":"null"
}
```



## 修改机构信息

根据提供的机构ID,修改机构信息，POST方式

>  /api/org/updateOrg

入参示例

```
 {
      "id":"xxx",
      "mrid": "xxx",
      "name": "xxx",
      "aliasName":"xxx",
      "province": "xxx",
      "city": "xxx",
      "county": "xxx",
      "address": "xxx",
      "contactPhone":"xxx",
      "remarks":"xxx",
      "parentOrgId":"xxxx",
      "token":"xxx"
   }
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述       |
| ------------ | -------- | -------- | ---------- |
| id           | BIGINT   | No       | 机构ID     |
| mrid         | String   | No       | 编码       |
| name         | String   | No       | 名称       |
| aliasName    | String   | No       | 简称/别名  |
| province     | String   | No       | 省         |
| city         | String   | No       | 城市       |
| county       | String   | No       | 区县       |
| address      | String   | No       | 详细地址   |
| contactPhone | String   | No       | 联系电话   |
| remarks      | String   | No       | 备注       |
| parentOrgId  | Long     | No       | 上级机构ID |
| token        | String   | NO       | token      |



调用成功返回示例



```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

#机构信息对象)

## 删除指定机构

根据提供的机构ID,删除机构信息，POST方式

>/api/org/deleteOrg

入参示例

```
{
       "id":"111",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述             |
| ------ | -------- | ---- | ---------------- |
| id     | Long     | No   | 要删除的机构主键 |
| token  | String   | YES  | token            |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```



# 职员模块API接口

职员模块提供的API包括职员查询、添加、修改等功能。

## API接口一览表

| 接口分类 | 接口描述 | API接口              | 权限            |
| :------: | :------- | :------------------- | --------------- |
| 职员操作 | 职员查询 | /api/user/getUser    | /XXXX/XXX/XXX/X |
| 职员操作 | 职员创建 | /api/user/addUser    |                 |
| 职员操作 | 职员修改 | /api/user/updateUser |                 |
| 职员操作 | 职员删除 | /api/user/deleteUser |                 |

## 职员查询

提供对职员信息的基本查询功能,POST方式。

>/api/user/getUser

入参示例

```
{
"userName":"xx",
"orgId":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述                                               |
| :------- | :------: | :--: | :------------------------------------------------- |
| userName |  String  | Yes  | 模糊查询职员名称，当职员名称为空时查询所有职员信息 |
| orgId    |  BIGINT  | Yes  | 所属机构ID                                         |
| token    |  String  |  NO  | token                                              |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data": [
    {
      "id": "xxxx",
      "account": "xxx",
      "password": "xxx",
      "userName": "xxx",
      "email":"xxx",
      "phone":"xxx",
      "orgId":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 变量名   | 变量类型 | 可为NULL | 描述               |
| -------- | -------- | -------- | ------------------ |
| id       | BIGINT   | No       | 主键(雪花算法生成) |
| account  | String   | No       | 登录账号           |
| password | String   | No       | 加密后的密码       |
| userName | String   | No       | 职员名称           |
| email    | String   | No       | 职员邮箱           |
| phone    | String   | No       | 职员联系电话       |
| orgId    | BIGINT   | No       | 所属机构ID         |

##  职员创建

根据提供的职员信息创建职员，POST方式。

>/api/user/addUser

入参示例

```
{
      "account": "xxx",
      "password": "xxx",
      "userName": "xxx",
      "email":"xxx",
      "phone":"xxx",
      "orgId":"xxx",
      "token":"xxx"
}
```

入参描述

| 变量名   | 变量类型 | 可为NULL | 描述         |
| -------- | -------- | -------- | ------------ |
| account  | String   | No       | 登录账号     |
| password | String   | No       | 加密后的密码 |
| userName | String   | No       | 职员名称     |
| email    | String   | No       | 职员邮箱     |
| phone    | String   | No       | 职员联系电话 |
| orgId    | BIGINT   | No       | 所属机构ID   |
| token    | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"创建成功",
"data":"null"
}
```



## 职员修改

根据提供的职员id,修改职员信息，POST方式。

>/api/user/updateUser



```
{
      "id":"xxx",
      "account": "xxx",
      "password": "xxx",
      "userName": "xxx",
      "email":"xxx",
      "phone":"xxx",
      "orgId":"xxx",
      "token":"xxx"
}
```

入参描述

| 变量名   | 变量类型 | 可为NULL | 描述               |
| -------- | -------- | -------- | ------------------ |
| id       | BIGINT   | No       | 主键(雪花算法生成) |
| account  | String   | No       | 登录账号           |
| password | String   | No       | 加密后的密码       |
| userName | String   | No       | 职员名称           |
| email    | String   | No       | 职员邮箱           |
| phone    | String   | No       | 职员联系电话       |
| orgId    | BIGINT   | No       | 所属机构ID         |
| token    | String   | NO       | token              |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

## 职员删除

根据提供的职员id,删除职员信息，POST方式。

> /api/user/deleteUser

入参示例

```
{
       "id":"123",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述           |
| ------ | -------- | ---- | -------------- |
| id     | BIGINT   | No   | 要删除的职员Id |
| token  | String   | NO   | token          |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

# 物模型模块API接口

物模型模块提供的API包括物模型查询、添加、修改等功能。

## API接口一览表

|    接口分类    | 接口描述       | API接口                           | 权限            |
| :------------: | :------------- | :-------------------------------- | --------------- |
| 物模型定义操作 | 物模型定义查询 | /api/devicemgr/getModel           | /XXXX/XXX/XXX/X |
| 物模型定义操作 | 物模型定义删除 | /api/devicemgr/deleteModel        |                 |
| 物模型定义操作 | 物模型定义新增 | /api/devicemgr/addModel           |                 |
| 物模型定义操作 | 物模型定义修改 | /api/devicemgr/updateModel        |                 |
| 物模型属性操作 | 物模型属性查询 | /api/devicemgr/getModelFiled      |                 |
| 物模型属性操作 | 物模型属性删除 | /api/devicemgr/deleteModelFiled   |                 |
| 物模型属性操作 | 物模型属性新增 | /api/devicemgr/addModelFiled      |                 |
| 物模型属性操作 | 物模型属性修改 | /api/devicemgr/updateModelFiled   |                 |
| 物模型方法操作 | 物模型方法查询 | /api/devicemgr/getModelService    |                 |
| 物模型方法操作 | 物模型方法删除 | /api/devicemgr/deleteModelService |                 |
| 物模型方法操作 | 物模型方法新增 | /api/devicemgr/addModelService    |                 |
| 物模型方法操作 | 物模型方法修改 | /api/devicemgr/updateModelService |                 |

## 物模型定义

### 物模型定义查询

提供获取所有物模型定义信息的功能，POST方式

/api/devicemgr/getModel

入参示例

```
{
"modelName":"xx",
"objectType":"xx",
"token":"xxx"
}
```

入参描述

| 参数名     | 参数类型 | 可选 | 描述         |
| :--------- | :------: | :--: | :----------- |
| modelName  |  String  | Yes  | 模型名称     |
| objectType |   INT    | Yes  | 设备类型编码 |
| token      |  String  |  NO  | token        |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data": [
    {
      "object_type": "xxxx",
      "id": "xxx",
      "iotModelCode": "xxx",
      "iotModelName": "xxx"
   },
    {
        ...
    }
  ]
}
```

| 变量名       | 变量类型 | 可为NULL | 描述         |
| ------------ | -------- | -------- | ------------ |
| object_type  | INT      | No       | 设备类型编码 |
| id           | BIGINT   | NO       | 模型ID       |
| iotModelCode | String   | No       | 模型编码     |
| iotModelName | String   | No       | 模型名称     |

### 物模型定义删除

根据提供的ID,删除物模型定义，POST方式

> /api/devicemgr/deleteModel

入参示例

```
{
"id":"123",
 "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述           |
| ------ | -------- | ---- | -------------- |
| id     | BIGINT   | No   | 要删除的模型ID |
| token  | String   | NO   | token          |

调用成功返回示例

```
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 物模型定义新增

根据添加的信息创建物模型定义，POST方式

/api/devicemgr/addModel

入参示例

```
{
      "object_type": "xxxx",
      "iotModelCode": "xxx",
      "iotModelName": "xxx",
       "token":"xxx"
}
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述         |
| ------------ | -------- | -------- | ------------ |
| object_type  | INT      | NO       | 设备类型编码 |
| iotModelCode | String   | NO       | 模型编码     |
| iotModelName | String   | NO       | 模型名       |
| token        | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 物模型定义修改

根据提供的ID,修改物模型定义，POST方式

/api/devicemgr/updateModel

入参示例

```
{
      "object_type": "xxxx",
      "id": "xxx",
      "iotModelCode": "xxx",
      "iotModelName": "xxx",
       "token":"xxx"
}
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述         |
| ------------ | -------- | -------- | ------------ |
| object_type  | INT      | No       | 设备类型编码 |
| id           | BIGINT   | NO       | 模型ID       |
| iotModelCode | String   | No       | 模型编码     |
| iotModelName | String   | No       | 模型名称     |
| token        | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

## 物模型属性

### 物模型属性查询

提供获取所有物模型属性的功能，POST方式

/api/devicemgr/getModelFiled

入参示例

```
{
"iotModelId":"xxx",
"attribute_name":"XX",
"token":"xxx"
}
```

入参描述

| 参数名         | 参数类型 | 可选 | 描述         |
| :------------- | :------: | :--: | :----------- |
| iotModelId     |  BIGINT  | yes  | 所属物模型ID |
| attribute_name |  String  | yes  | 属性名称     |
| token          |  String  |  NO  | token        |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "id": "xxxx",
      "iotModelId": "xxx",
      "attributeCode": "xxx",
      "attributeName": "xxx",
        "attributeType","xxx",
        "porder":"xxx"
   },
    {
        ...
    }
  ]

}
```

| 变量名        | 变量类型 | 可为NULL | 描述         |
| ------------- | -------- | -------- | ------------ |
| id            | BIGINT   | NO       | 属性主键ID   |
| iotModelId    | BIGINT   | NO       | 所属物模型ID |
| attributeCode | String   | NO       | 属性编码     |
| attributeName | String   | NO       | 属性名称     |
| attributeType | INT      | NO       | 量测类型     |
| porder        | INT      | NO       | 测点序号     |

### 物模型属性删除

根据提供的ID,删除物模型属性，POST方式

> /api/devicemgr/deleteModelFiled

入参示例

```
{
      "id":"123",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述               |
| ------ | -------- | ---- | ------------------ |
| id     | BIGINT   | NO   | 要删除的属性主键ID |
| token  | String   | NO   | token              |

调用成功返回示例

```
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 物模型属性新增

根据添加的信息创建物模型属性，POST方式

/api/devicemgr/addModelFiled

入参示例

```
{
     
      "iotModelId": "xxx",
      "attributeCode": "xxx",
      "attributeName": "xxx",
      "attributeType","xxx",
      "porder":"xxx",
      "token":"xxx"
}
```

入参描述

| 变量名        | 变量类型 | 可为NULL | 描述         |
| ------------- | -------- | -------- | ------------ |
| iotModelId    | BIGINT   | NO       | 所属物模型ID |
| attributeCode | String   | NO       | 属性编码     |
| attributeName | String   | NO       | 属性名称     |
| attributeType | INT      | NO       | 量测类型     |
| porder        | INT      | NO       | 测点序号     |
| token         | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 物模型属性修改

根据提供的ID,修改物模型属性，POST方式

/api/devicemgr/updateModelFiled

入参示例

```
{
      "id": "xxxx",
      "iotModelId": "xxx",
      "attributeCode": "xxx",
      "attributeName": "xxx",
      "attributeType","xxx",
      "porder":"xxx",
      "token":"xxx"
}
```

入参描述

| 变量名        | 变量类型 | 可为NULL | 描述         |
| ------------- | -------- | -------- | ------------ |
| id            | BIGINT   | NO       | 属性主键ID   |
| iotModelId    | BIGINT   | NO       | 所属物模型ID |
| attributeCode | String   | NO       | 属性编码     |
| attributeName | String   | NO       | 属性名称     |
| attributeType | INT      | NO       | 量测类型     |
| porder        | INT      | NO       | 测点序号     |
| token         | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

## 物模型方法

### 物模型方法查询

提供获取所有物模型方法的功能，POST方式

/api/devicemgr/getModelService

入参示例

```
{
       "modelId":"xxx",
       "token":"xxx"
}
```

入参描述

| 参数名  | 参数类型 | 可选 | 描述         |
| :------ | :------: | :--: | :----------- |
| modelId |  String  |  no  | 所属物模型ID |
| token   |  String  |  NO  | token        |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data": [
    {
      "id": "xxxx",
      "iotModelId": "xxx",
      "serviceCode": "xxx",
      "serviceName": "xxx",
      "serviceType","xxx",
      "porder":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 变量名      | 变量类型 | 可为NULL | 描述         |
| ----------- | -------- | -------- | ------------ |
| id          | BIGINT   | NO       | 属性主键ID   |
| iotModelId  | String   | NO       | 所属物模型ID |
| serviceCode | String   | NO       | 动作编码     |
| serviceName | String   | NO       | 动作名称     |
| serviceType | INT      | NO       | 量测类型     |
| porder      | INT      | NO       | 测点序号     |

### 物模型方法删除

根据提供的ID,删除物模型方法，POST方式

> /api/devicemgr/deleteModelService

入参示例

```
{
	   "id":"123",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述               |
| ------ | -------- | ---- | ------------------ |
| id     | BIGINT   | No   | 要删除的属性主键ID |
| token  | String   | NO   | token              |

调用成功返回示例

```
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 物模型方法新增

根据添加的信息创建物模型方法，POST方式

/api/devicemgr/addModelService

入参示例

```
{
      "serviceCode": "xxx",
      "serviceCode": "xxx",
      "serviceName": "xxx",
      "serviceType","xxx",
       "porder":"xxx",
       "token":"xxx"
}
```

入参描述

| 变量名      | 变量类型 | 可为NULL | 描述         |
| ----------- | -------- | -------- | ------------ |
| iotModelId  | Long     | NO       | 所属物模型ID |
| serviceCode | String   | NO       | 动作编码     |
| serviceName | String   | NO       | 动作名称     |
| serviceType | Long     | NO       | 量测类型     |
| porder      | Long     | NO       | 测点序号     |
| token       | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 物模型方法修改

根据提供的ID,修改物模型方法，POST方式

/api/devicemgr/updateModelService

入参示例

```
{
      "id": "xxxx",
      "iotModelId": "xxx",
      "serviceCode": "xxx",
      "serviceName": "xxx",
       "serviceType","xxx",
       "porder":"xxx",
       "token":"xxx"
}
```

入参描述

| 变量名      | 变量类型 | 可为NULL | 描述         |
| ----------- | -------- | -------- | ------------ |
| id          | BIGINT   | NO       | 属性主键ID   |
| iotModelId  | String   | NO       | 所属物模型ID |
| serviceCode | String   | NO       | 动作编码     |
| serviceName | String   | NO       | 动作名称     |
| serviceType | INT      | NO       | 量测类型     |
| porder      | INT      | NO       | 测点序号     |
| token       | String   | NO       | token        |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

# 设备基础属性模块API接口

## API接口一览表

|     接口分类     | 接口描述         | API接口                         | 权限            |
| :--------------: | :--------------- | :------------------------------ | --------------- |
| 设备基础属性操作 | 设备基础属性查询 | /api/devicemgr/getEquipment     | /XXXX/XXX/XXX/X |
| 设备基础属性操作 | 设备基础属性删除 | /api/devicemgr/deleteEquipment  |                 |
| 设备基础属性操作 | 设备基础属性新增 | /api/devicemgr/updateModelFiled |                 |
| 设备基础属性操作 | 设备基础属性修改 | /api/devicemgr/updateModelFiled |                 |

## 设备基础属性查询

提供获取所有设备基础属性的功能，POST方式

/api/devicemgr/getEquipment

入参示例

```
{
"name":"xxx",
"parentEquipmentId":"XX",
"orgId":"XXX",
"token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述     |
| :----- | :------: | :--: | :------- |
| name   |  String  | YES  | 设备名称 |
| token  |  String  |  NO  | token    |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data": [
    {
      "id": "xxxx",
      "objectType": "xxx",
      "code": "xxx",
      "name": "xxx",
      "madeinfactory","xxx",
      "model":"xxx",
      "location","xxx",
      "longitude":"xxx",
      "latitude": "xxx",
      "installDate": "xxx",
      "remarks","xxx",
      "orgId":"xxx",
      "parentEquipmentId","xxx",
      "iotModelId":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 变量名            | 变量类型 | 可为NULL | 描述          |
| :---------------- | :------- | :------- | :------------ |
| id                | BIGINT   | NO       | 设备ID        |
| objectType        | INT      | NO       | 设备类型编码  |
| code              | String   | NO       | 设备编码      |
| name              | String   | NO       | 设备名称      |
| madeinfactory     | String   | NO       | 制造商        |
| model             | String   | NO       | 型号规格      |
| location          | String   | NO       | 安装位置      |
| longitude         | DECIMAL  | NO       | 安装位置_经度 |
| latitude          | DECIMAL  | NO       | 安装位置_纬度 |
| installDate       | DATETIME | NO       | 安装日期      |
| remarks           | String   | NO       | 备注          |
| orgId             | BIGINT   | NO       | 设备所属机构  |
| parentEquipmentId | BIGINT   | NO       | 上级设备ID    |
| iotModelId        | BIGINT   | NO       | 对应物模型    |

## 设备基础属性删除

根据提供的ID,删除设备基础属性，POST方式

> /api/devicemgr/deleteEquipment

入参示例

```
{
       "id":"123",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述           |
| ------ | -------- | ---- | -------------- |
| id     | BIGINT   | NO   | 要删除的设备ID |
| token  | String   | NO   | token          |

调用成功返回示例

```
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

## 设备基础属性新增

根据添加的信息创建设备基础属性，POST方式

/api/devicemgr/addEquipment

入参示例

```
{  
      "objectType": "xxx",
      "code": "xxx",
      "name": "xxx",
      "madeinfactory","xxx",
      "model":"xxx",
      "location","xxx",
      "longitude":"xxx",
      "latitude": "xxx",
      "installDate": "xxx",
      "remarks","xxx",
      "orgId":"xxx",
      "parentEquipmentId","xxx",
      "iotModelId":"xxx",
       "token":"xxx"
}
```

入参描述

| 变量名            | 变量类型 | 可为NULL | 描述          |
| :---------------- | :------- | :------- | :------------ |
| objectType        | INT      | NO       | 设备类型编码  |
| code              | String   | NO       | 设备编码      |
| name              | String   | NO       | 设备名称      |
| madeinfactory     | String   | NO       | 制造商        |
| model             | String   | NO       | 型号规格      |
| location          | String   | NO       | 安装位置      |
| longitude         | DECIMAL  | NO       | 安装位置_经度 |
| latitude          | DECIMAL  | NO       | 安装位置_纬度 |
| installDate       | DATETIME | NO       | 安装日期      |
| remarks           | String   | NO       | 备注          |
| orgId             | BIGINT   | NO       | 设备所属机构  |
| parentEquipmentId | BIGINT   | NO       | 上级设备ID    |
| iotModelId        | BIGINT   | NO       | 对应物模型    |
| token             | String   | NO       | token         |

调用成功返回示例

```
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

## 设备基础属性修改

根据提供的ID,修改设备基础属性，POST方式

/api/devicemgr/updateModelFiled

入参示例

```
{
     "id":"xxx",
     "objectType": "xxx",
      "code": "xxx",
      "name": "xxx",
      "madeinfactory","xxx",
      "model":"xxx",
      "location","xxx",
      "longitude":"xxx",
      "latitude": "xxx",
      "installDate": "xxx",
      "remarks","xxx",
      "orgId":"xxx",
      "parentEquipmentId","xxx",
      "iotModelId":"xxx",
      "token":"xxx"
}
```

入参描述

| 变量名            | 变量类型 | 可为NULL | 描述          |
| :---------------- | :------- | :------- | :------------ |
| id                | BIGINT   | NO       | 设备ID        |
| objectType        | INT      | NO       | 设备类型编码  |
| code              | String   | NO       | 设备编码      |
| name              | String   | NO       | 设备名称      |
| madeinfactory     | String   | NO       | 制造商        |
| model             | String   | NO       | 型号规格      |
| location          | String   | NO       | 安装位置      |
| longitude         | DECIMAL  | NO       | 安装位置_经度 |
| latitude          | DECIMAL  | NO       | 安装位置_纬度 |
| installDate       | DATETIME | NO       | 安装日期      |
| remarks           | String   | NO       | 备注          |
| orgId             | BIGINT   | NO       | 设备所属机构  |
| parentEquipmentId | BIGINT   | NO       | 上级设备ID    |
| iotModelId        | BIGINT   | NO       | 对应物模型    |
| token             | String   | NO       | token         |

调用成功返回示例

```
{
"code":"200",
"msg":"修改成功",
"data":"null"
}
```

# 权限管理模块API接口

## API接口一览表

|   接口分类   | 接口描述     | API接口                       | 权限            |
| :----------: | :----------- | :---------------------------- | --------------- |
| 系统权限操作 | 系统权限查询 | /api/user/getSysAuthoritys    | /XXXX/XXX/XXX/X |
| 系统权限操作 | 新增系统权限 | /api/user/addSysAuthority     |                 |
| 系统权限操作 | 删除系统权限 | /api/user/deleteSysAuthority  |                 |
| 系统权限操作 | 编辑系统权限 | /api/user/updateSysAuthority  |                 |
| 系统角色操作 | 系统角色查询 | /api/user/getSysRole          |                 |
| 系统角色操作 | 系统角色删除 | /api/user/deleteSysRole       |                 |
| 系统角色操作 | 系统角色新增 | /api/user/addSysRole          |                 |
| 系统角色操作 | 角色权限查询 | /api/user/getAuthorityById    |                 |
| 系统角色操作 | 角色权限编辑 | /api/user/updateAuthorityById |                 |
| 菜单管理操作 | 系统菜单查询 | /api/user/getSysMenuList      |                 |
| 菜单管理操作 | 系统菜单删除 | /api/user/addSysMenu          |                 |
| 菜单管理操作 | 系统菜单新增 | /api/user/deleteSysMenu       |                 |
| 菜单管理操作 | 系统菜单编辑 | /api/user/updateSysMenu       |                 |

## 系统权限管理

### 系统权限查询

提供获取所有系统权限的功能，POST方式

/api/user/getSysAuthoritys

入参示例

```
{
       "authorityName":"xxx",
       "token":"xxx"
}
```

入参描述

| 参数名        | 参数类型 | 可选 | 描述                           |
| :------------ | :------: | :--: | :----------------------------- |
| authorityName |  String  | yes  | 权限名称为空时查询所有系统角色 |
| token         |  String  |  NO  | token                          |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "id": "xxxx",
      "authorityCode": "xxx",
      "authorityName": "xxx",
     
   },
    {
        ...
    }
  ]
}
```

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- | -------- |
| id            | BIGINT   | NO       | 主键id   |
| authorityCode | string   | NO       | 权限编码 |
| authorityName | string   | NO       | 权限名称 |



### 新增系统权限

根据添加的信息创建系统权限，POST方式

/api/user/addSysAuthority

入参示例

```
{
"authorityCode":"xxx",
"authorityName":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名        | 参数类型 | 可选 | 描述     |
| :------------ | :------: | :--: | :------- |
| authorityCode |  String  |  NO  | 权限编码 |
| authorityName |  String  |  NO  | 权限名称 |
| token         |  String  |  NO  | token    |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 删除系统权限

根据提供的ID,删除系统权限，POST方式

/api/user/deleteSysAuthority

入参示例

```
{
       "id":"xxx",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述  |
| :----- | :------: | :--: | :---- |
| id     |  BIGINT  |  NO  | 主键  |
| token  |  String  |  NO  | token |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 编辑系统权限

根据提供的ID,修改系统权限，POST方式

/api/user/updateSysAuthority

入参示例

```
{
"id":"xxx",
"authorityCode":"xxx",
"authorityName":"xxx",
"token":"xxx"
}
```

入参描述

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- | -------- |
| id            | BIGINT   | NO       | 主键id   |
| authorityCode | string   | NO       | 权限编码 |
| authorityName | string   | NO       | 权限名称 |
| token         | String   | NO       | token    |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```



## 角色维护

### 系统角色查询

提供获取所有系统角色的功能，POST方式

/api/user/getSysRole

入参示例

```
{
       "roleName":"xxx",,
       "token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述                           |
| :------- | :------: | :--: | :----------------------------- |
| roleName |  String  | YES  | 系统角色为空时查询所有系统角色 |
| token    |  String  |  NO  | token                          |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "id": "xxxx",
      "roleCode": "xxx",
      "roleName": "xxx",
     
   },
    {
        ...
    }
  ]
}
```

| 变量名   | 变量类型 | 可为NULL | 描述     |
| -------- | -------- | -------- | -------- |
| id       | BIGINT   | No       | 主键id   |
| roleCode | string   | No       | 角色编码 |
| roleName | string   | No       | 角色名称 |

### 系统角色删除

根据提供的ID,删除系统角色，POST方式

/api/user/deleteSysRole

入参示例

```
{
       "id":"xxx",,
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述       |
| :----- | :------: | :--: | :--------- |
| id     |  BIGINT  |  NO  | 系统角色id |
| token  |  String  |  NO  | token      |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 系统角色新增

根据添加的信息创建系统角色，POST方式

/api/user/addSysRole

入参示例

```
{
"id":"xxx",
"roleCode":"XX",
"roleName":"XX",
"authorityList":["12","12"],
"token":"xxx"
}
```

入参描述

| 参数名        |   参数类型   | 可选 | 描述         |
| :------------ | :----------: | :--: | :----------- |
| id            |    BIGINT    |  no  | 系统角色id   |
| roleCode      |    String    |  no  | 角色编码     |
| roleName      |    String    |  no  | 角色名称     |
| authorityList | List<String> | yes  | 角色的权限id |
| token         |    String    |  NO  | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 角色权限查询

提供获取所有角色权限的功能，POST方式

/api/user/getAuthorityById

入参示例

```
{
       "id":"xxx",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述       |
| :----- | :------: | :--: | :--------- |
| id     |  BIGINT  |  NO  | 系统角色id |
| token  |  String  |  NO  | token      |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "authorityCode": "xxxx",
      "authorityName": "xxx",
      "id": "xxx",
   },{
       
   }
  ]
}
```

| 变量名        | 变量类型 | 可为NULL | 描述     |
| ------------- | -------- | -------- | -------- |
| id            | BIGINT   | No       | 权限ID   |
| authorityCode | string   | No       | 权限编码 |
| authorityName | string   | No       | 权限名称 |

api/user/addSysRole

入参示例

```
{
"id":"xxx",
"roleCode":"XX",
"roleName":"XX",
"authorityList":["12","12"],
"token":"xxx"
}
```

入参描述

| 参数名        |   参数类型   | 可选 | 描述         |
| :------------ | :----------: | :--: | :----------- |
| id            |    BIGINT    |  no  | 系统角色id   |
| roleCode      |    String    |  no  | 角色编码     |
| roleName      |    String    |  no  | 角色名称     |
| authorityList | List<String> | yes  | 角色的权限id |
| token         |    String    |  NO  | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 角色权限编辑

根据提供的ID,修改角色权限，POST方式

/api/user/updateAuthorityById

入参示例

```
{
"id":"xxx",
"roleName":"XX",
"authorityList":["12","12"],
"token":"xxx"
}
```

入参描述

| 参数名        |   参数类型   | 可选 | 描述         |
| :------------ | :----------: | :--: | :----------- |
| id            |    BIGINT    |  no  | 系统角色id   |
| roleName      |    String    |  no  | 角色名称     |
| authorityList | List<String> | yes  | 角色的权限id |
| token         |    String    |  NO  | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```

## 菜单管理

### 系统菜单查询

提供获取所有系统菜单的功能，POST方式

/api/user/getSysMenuList

入参示例

```
{
"menuName":"xxx",
"parentMenuId":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名       | 参数类型 | 可选 | 描述                               |
| :----------- | :------: | :--: | :--------------------------------- |
| menuName     |  String  | yes  | 系统菜单名称为空时查询所有系统角色 |
| parentMenuId |  BIGINT  | yes  | 上级菜单ID                         |
| token        |  String  |  NO  | token                              |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "id": "xxxx",
      "menuName": "xxx",
        "menuOrder":"XX",
        "menuIcon":"XX",
      "funType": "xxx",
        "funParam": "xxxx",
      "authorityId": "xxx",
        "parentMenuId": "xxxx"
   },
    {
        ...
    }
  ]
}
```

| 变量名       | 变量类型 | 可为NULL | 描述         |
| ------------ | -------- | -------- | ------------ |
| id           | BIGINT   | No       | 菜单ID       |
| menuName     | string   | No       | 菜单名称     |
| menuOrder    | INT      | No       | 菜单排列顺序 |
| menuIcon     | string   | No       | 菜单图标名称 |
| funType      | INT      | No       | 菜单操作类型 |
| funParam     | string   | No       | 菜单操作参数 |
| authorityId  | BIGINT   | No       | 权限ID       |
| parentMenuId | BIGINT   | No       | 上级菜单ID   |

### 系统菜单新增

根据添加的信息创建系统菜单，POST方式

/api/user/addSysMenu

入参示例

```
{
      "menuName": "xxx",
        "menuOrder":"XX",
        "menuIcon":"XX",
      "funType": "xxx",
        "funParam": "xxxx",
      "authorityId": "xxx",
        "parentMenuId": "xxxx"
        "menuName":"xxx",
        "parentMenuId":"xxx"
        "authorityList":["12","12"],
       "token":"xxx"
}
```

入参描述

| 变量名       | 变量类型 | 可为NULL | 描述         |
| ------------ | -------- | -------- | ------------ |
| menuName     | string   | No       | 菜单名称     |
| menuOrder    | INT      | No       | 菜单排列顺序 |
| menuIcon     | string   | No       | 菜单图标名称 |
| funType      | INT      | No       | 菜单操作类型 |
| funParam     | string   | No       | 菜单操作参数 |
| authorityId  | BIGINT   | No       | 权限ID       |
| parentMenuId | BIGINT   | No       | 上级菜单ID   |
| token        | String   | NO       | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 系统菜单删除

根据提供的ID,删除系统菜单，POST方式

/api/user/deleteSysMenu

入参示例

```
{
     "id":"xx",
       "token":"xxx"
}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述   |
| :----- | :------: | :--: | :----- |
| id     |  String  |  no  | 菜单id |
| token  |  String  |  NO  | token  |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

### 系统菜单编辑

根据提供的ID,修改系统菜单，POST方式

/api/user/updateSysMenu

入参示例

```
{
"id":"xxx",
      "menuName": "xxx",
        "menuOrder":"XX",
        "menuIcon":"XX",
      "funType": "xxx",
        "funParam": "xxxx",
      "authorityId": "xxx",
        "parentMenuId": "xxxx"
        "menuName":"xxx",
        "parentMenuId":"xxx"
        "authorityList":["12","12"],
       "token":"xxx"
}
```

入参描述

| 变量名        | 变量类型     | 可为NULL | 描述         |
| ------------- | ------------ | -------- | ------------ |
| id            | string       | No       | 菜单id       |
| menuName      | string       | No       | 菜单名称     |
| menuOrder     | string       | No       | 菜单排列顺序 |
| menuIcon      | string       | No       | 菜单图标名称 |
| funType       | string       | No       | 菜单操作类型 |
| funParam      | string       | No       | 菜单操作参数 |
| authorityId   | string       | No       | 权限ID       |
| parentMenuId  | string       | No       | 上级菜单ID   |
| authorityList | List<String> | yes      | 角色的权限id |
| token         | String       | NO       | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```

# 链路模块API接口

## API接口一览表

|   接口分类   | 接口描述     | API接口                       | 权限            |
| :----------: | :----------- | :---------------------------- | --------------- |
| 链路映射操作 | 链路映射查询 | /api/link/getImptabmapping    | /XXXX/XXX/XXX/X |
| 链路映射操作 | 链路映射新增 | /api/link/addImptabmapping    |                 |
| 链路映射操作 | 链路映射修改 | /api/link/updateImptabmapping |                 |
| 链路映射操作 | 链路映射删除 | /api/link/deleteImptabmapping |                 |
| 通讯链路操作 | 通讯链路查询 | /api/link/getCommun           |                 |
| 通讯链路操作 | 通讯链路新增 | /api/link/addCommun           |                 |
| 通讯链路操作 | 通讯链路修改 | /api/user/addSysRole          |                 |
| 通讯链路操作 | 通讯链路删除 | /api/link/deleteICommun       |                 |
| 系统节点操作 | 系统节点查询 | /api/link/getNode             |                 |
| 系统节点操作 | 系统节点新增 | /api/link/addNode             |                 |
| 系统节点操作 | 系统节点修改 | /api/link/updateNode          |                 |
| 系统节点操作 | 系统节点删除 | /api/link/deleteINode         |                 |

## 链路映射

### 链路映射查询

提供获取所有链路映射的功能，POST方式

/api/link/getImptabmapping

入参示例

```
{

"linkId":"xxx",
"equipmentId":"xxx",
"token":"xxx"

}
```

入参描述

| 参数名      | 参数类型 | 可选 | 描述       |
| :---------- | :------: | :--: | :--------- |
| linkId      |  BIGINT  |  no  | 对应链路ID |
| equipmentId |  BIGINT  |  no  | 对应设备ID |
| token       |  String  |  NO  | token      |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
      "id":"xxx",
       "linkId":"xxx",
       "equipmentId":"xxx",
       "equipmentAttribute":"xxx",
       "equipmentService":"xxx",
        "porder":"xxx",
        "params":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 参数名             | 参数类型 | 可选 | 描述         |
| :----------------- | :------: | :--: | :----------- |
| id                 |  BIGINT  |  no  | 主键         |
| linkId             |  BIGINT  |  no  | 对应链路ID   |
| equipmentId        |  BIGINT  |  no  | 对应设备ID   |
| equipmentAttribute |  String  |  no  | 备属性       |
| equipmentService   |  String  |  no  | 对应设备服务 |
| porder             |   INT    |  no  | 测点序号     |
| params             |   TEXT   |  no  | 参数         |

### 链路映射新增

根据添加的信息创建链路映射，POST方式

/api/link/addImptabmapping

入参示例

```
{
      "id":"xxx",
       "linkId":"xxx",
       "equipmentId":"xxx",
       "equipmentAttribute":"xxx",
       "equipmentService":"xxx",
        "porder":"xxx",
        "params":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名             | 参数类型 | 可选 | 描述         |
| :----------------- | :------: | :--: | :----------- |
| linkId             |  BIGINT  |  no  | 对应链路ID   |
| equipmentId        |  BIGINT  |  no  | 对应设备ID   |
| equipmentAttribute |  String  |  no  | 备属性       |
| equipmentService   |  String  |  no  | 对应设备服务 |
| porder             |   INT    |  no  | 测点序号     |
| params             |   TEXT   |  no  | 参数         |
| token              |  String  |  NO  | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 链路映射修改

根据提供的ID,修改链路映射，POST方式

/api/link/updateImptabmapping

入参示例

```
{
      "id":"xxx",
       "linkId":"xxx",
       "equipmentId":"xxx",
       "equipmentAttribute":"xxx",
       "equipmentService":"xxx",
        "porder":"xxx",
        "params":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名             | 参数类型 | 可选 | 描述         |
| :----------------- | :------: | :--: | :----------- |
| linkId             |  BIGINT  |  NO  | 对应链路ID   |
| equipmentId        |  BIGINT  |  NO  | 对应设备ID   |
| equipmentAttribute |  String  |  NO  | 备属性       |
| equipmentService   |  String  |  NO  | 对应设备服务 |
| porder             |   INT    |  NO  | 测点序号     |
| params             |   TEXT   |  NO  | 参数         |
| token              |  String  |  NO  | token        |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```

### 链路映射删除

根据提供的ID,删除链路映射，POST方式

/api/link/deleteImptabmapping

入参示例

```
{

       "id":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述  |
| :----- | :------: | :--: | :---- |
| id     |  BIGINT  |  NO  | 主键  |
| token  |  String  |  NO  | token |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

## 通讯链路

### 通讯链路查询

提供获取所有通讯链路的功能，POST方式

/api/link/getCommun

入参示例

```
{
"linkName":"xxx"
"nodeId":"XXX",
"token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述           |
| :------- | :------: | :--: | :------------- |
| linkName |  STRING  |  NO  | 链路名称       |
| nodeId   |  BIGINT  |  NO  | 所属系统节点ID |
| token    |  String  |  NO  | token          |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
       "id":"xxx",
       "linkName":"xxx",
       "protocol":"xxx",
       "params":"xxx",
       "nodeId":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 参数名   | 参数类型 | 可选 | 描述           |
| :------- | :------: | :--: | :------------- |
| id       | VARCHAR  |  NO  | 链路主键       |
| linkName |  BIGINT  |  NO  | 链路名称       |
| protocol |   INT    |  NO  | 通讯协议       |
| params   |   TEXT   |  NO  | 协议参数       |
| nodeId   |  BIGINT  |  NO  | 所属系统节点ID |

### 通讯链路新增

根据添加的信息创建通讯链路，POST方式

/api/link/addCommun

入参示例

```
{
      "linkName":"xxx",
       "protocol":"xxx",
       "params":"xxx",
       "nodeId":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述           |
| :------- | :------: | :--: | :------------- |
| linkName |  BIGINT  |  NO  | 链路名称       |
| protocol |   INT    |  NO  | 通讯协议       |
| params   |   TEXT   |  NO  | 协议参数       |
| nodeId   |  BIGINT  |  NO  | 所属系统节点ID |
| token    |  String  |  NO  | token          |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 通讯链路修改

根据提供的ID,修改通讯链路，POST方式

/api/link/updateCommun

入参示例

```
{
       "id":"xxx",
       "linkName":"xxx",
       "protocol":"xxx",
       "params":"xxx",
       "nodeId":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述           |
| :------- | :------: | :--: | :------------- |
| id       | VARCHAR  |  NO  | 链路主键       |
| linkName |  BIGINT  |  NO  | 链路名称       |
| protocol |   INT    |  NO  | 通讯协议       |
| params   |   TEXT   |  NO  | 协议参数       |
| nodeId   |  BIGINT  |  NO  | 所属系统节点ID |
| token    |  String  |  NO  | token          |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```

### 通讯链路删除

根据提供的ID,删除通讯链路，POST方式

/api/link/deleteICommun

入参示例

```
{

"id":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述  |
| :----- | :------: | :--: | :---- |
| id     |  BIGINT  |  NO  | 主键  |
| token  |  String  |  NO  | token |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

## 系统节点

### 系统节点查询

提供获取所有系统节点的功能，POST方式

/api/link/getNode

入参示例

```
{
"nodeName":"xxx"
"nodeIp":"XXX",
"orgId":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述     |
| :------- | :------: | :--: | :------- |
| nodeName |  STRING  | YES  | 节点名称 |
| nodeIp   |  STRING  | YES  | 节点IP   |
| orgId    |  BIGINT  | YES  | 所属机构 |
| token    |  String  |  NO  | token    |

调用成功返回示例

```json
{
    "code":"200",
    "msg":"调用成功",
    "data":[
    {
       "id":"xxx",
       "nodeName":"xxx",
       "nodeIp":"xxx",
       "orgId":"xxx"
   },
    {
        ...
    }
  ]
}
```

| 参数名   | 参数类型 | 可选 | 描述       |
| :------- | :------: | :--: | :--------- |
| id       |  BIGINT  |  no  | 系统节点ID |
| nodeName |  STRING  |  no  | 节点名称   |
| nodeIp   |  STRING  |  no  | 节点IP     |
| orgId    |  BIGINT  |  no  | 所属机构   |

### 系统节点新增

根据添加的信息创建系统节点，POST方式

/api/link/addNode

入参示例

```
{
"nodeName":"xxx"
"nodeIp":"XXX",
"orgId":"xxx",
"token":"xxx"
}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述     |
| :------- | :------: | :--: | :------- |
| nodeName |  STRING  |  NO  | 节点名称 |
| nodeIp   |  STRING  |  NO  | 节点IP   |
| orgId    |  BIGINT  |  NO  | 所属机构 |
| token    |  String  |  NO  | token    |

调用成功返回示例

```json
{
"code":"200",
"msg":"新增成功",
"data":"null"
}
```

### 系统节点修改

根据提供的ID,修改系统节点，POST方式

/api/link/updateNode

入参示例

```
{
      "id":"xxx",
       "nodeName":"xxx",
       "nodeIp":"xxx",
       "orgId":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名   | 参数类型 | 可选 | 描述       |
| :------- | :------: | :--: | :--------- |
| id       |  BIGINT  |  NO  | 系统节点ID |
| nodeName |  STRING  |  NO  | 节点名称   |
| nodeIp   |  STRING  |  NO  | 节点IP     |
| orgId    |  BIGINT  |  NO  | 所属机构   |
| token    |  String  |  NO  | token      |

调用成功返回示例

```json
{
"code":"200",
"msg":"编辑成功",
"data":"null"
}
```

### 系统节点删除

根据提供的ID,删除系统节点，POST方式

/api/link/deleteINode

入参示例

```
{

       "id":"xxx",
       "token":"xxx"

}
```

入参描述

| 参数名 | 参数类型 | 可选 | 描述  |
| :----- | :------: | :--: | :---- |
| id     |  BIGINT  |  NO  | 主键  |
| token  |  String  |  NO  | token |

调用成功返回示例

```json
{
"code":"200",
"msg":"删除成功",
"data":"null"
}
```

 